fn verify_operand_defs(graph: &ScGraph, errors: &mut Vec<VerifyError>)Expand description
Check that every operand references a value defined by an earlier op.
fn verify_operand_defs(graph: &ScGraph, errors: &mut Vec<VerifyError>)Check that every operand references a value defined by an earlier op.